@@ -3,7 +3,11 @@ package App::Gimei;
 use warnings;
 use v5.22;
 
-use version; our $VERSION = version->declare("v0.2.1");
+use version; our $VERSION = version->declare("v0.2.2");
+
+use App::Gimei::Runner;
+use App::Gimei::Parser;
+use App::Gimei::Generator;
 
 1;
 __END__
